@@ -88,6 +88,14 @@ pub struct MetadataList {
     pub meta: HashMap<String, HashMap<String, usize>>,
 }
 
+/// A sorting order.
+#[derive(Clone, Debug, Deserialize, Hash, Serialize, PartialEq, Eq)]
+#[serde(rename_all = "snake_case")]
+pub enum SortOrder {
+    CreationAscending,
+    CreationDescending,
+}
+
 /// A query that can be sent to a Menmos cluster.
 #[derive(Clone, Debug, Deserialize, Hash, Serialize, PartialEq, Eq)]
 #[serde(deny_unknown_fields)]
@@ -98,6 +106,7 @@ pub struct Query {
     pub size: usize,
     pub sign_urls: bool,
     pub facets: bool, // TODO: Permit requesting facets for specific tags instead of doing it for all.
+    pub sort_order: SortOrder,
 }
 
 impl Query {
@@ -106,6 +115,7 @@ impl Query {
         Ok(self)
     }
 
+    #[must_use]
     pub fn and_tag<S: Into<String>>(mut self, tag: S) -> Self {
         let new_expr = Expression::Tag { tag: tag.into() };
         self.expression = Expression::And {
@@ -114,6 +124,7 @@ impl Query {
         self
     }
 
+    #[must_use]
     pub fn and_meta<K: Into<String>, V: Into<String>>(mut self, k: K, v: V) -> Self {
         let new_expr = Expression::KeyValue {
             key: k.into(),
@@ -125,6 +136,7 @@ impl Query {
         self
     }
 
+    #[must_use]
     pub fn and_parent<P: Into<String>>(mut self, p: P) -> Self {
         let new_expr = Expression::Parent { parent: p.into() };
         self.expression = Expression::And {
@@ -133,20 +145,28 @@ impl Query {
         self
     }
 
+    #[must_use]
     pub fn with_from(mut self, f: usize) -> Self {
         self.from = f;
         self
     }
 
+    #[must_use]
     pub fn with_size(mut self, s: usize) -> Self {
         self.size = s;
         self
     }
 
+    #[must_use]
     pub fn with_facets(mut self, f: bool) -> Self {
         self.facets = f;
         self
     }
+
+    pub fn with_sort_order(mut self, sort_order: SortOrder) -> Self {
+        self.sort_order = sort_order;
+        self
+    }
 }
 
 impl Default for Query {
@@ -157,6 +177,7 @@ impl Default for Query {
             size: 30,
             sign_urls: true,
             facets: false,
+            sort_order: SortOrder::CreationAscending,
         }
     }
 }
@@ -179,6 +200,7 @@ impl RoutingConfig {
         }
     }
 
+    #[must_use]
     pub fn with_route<K: Into<String>, V: Into<String>>(
         mut self,
         field_value: K,
@@ -210,6 +232,13 @@ pub struct MoveInformation {
     pub destination_node: StorageNodeInfo,
 }
 
+#[derive(Clone, Copy, Debug, Deserialize, Serialize, PartialEq)]
+#[serde(rename_all = "snake_case")]
+pub enum RoutingAlgorithm {
+    RoundRobin,
+    MinSize,
+}
+
 #[async_trait]
 pub trait BlobIndexer {
     async fn pick_node_for_blob(
